==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/ja-JP/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => '付属品をチェックインしました',
    'Accessory_Checkout_Notification' => '付属品をチェックアウトしました',
    'Asset_Checkin_Notification' => '資産をチェックインしました',
    'Asset_Checkout_Notification' => '資産はチェックアウトされました',
    'Confirm_Accessory_Checkin' => 'アクセサリーのチェックインを承認してください。',
    'Confirm_Asset_Checkin' => '資産チェックインを承認してください。',
    'Confirm_accessory_delivery' => 'アクセサリーの受取りを承認してください。',
    'Confirm_asset_delivery' => '資産の受取りを承認してください。',
    'Confirm_consumable_delivery' => '消耗品の受取りを承認してください。',
    'Confirm_license_delivery' => 'ライセンスの受取りを承認してください。',
    'Consumable_checkout_notification' => '消耗品はチェックアウトしました',
    'Days' => '日数',
    'Expected_Checkin_Date' => 'チェックアウトされた資産は:date にチェックインされる予定です',
    'Expected_Checkin_Notification' => 'リマインダー: :name のチェックイン期限が近づいています',
    'Expected_Checkin_Report' => '予想される資産チェックインレポート',
    'Expiring_Assets_Report' => '保証切れ資産レポート',
    'Expiring_Licenses_Report' => '有効期限切れのライセンスレポート',
    'Item_Request_Canceled' => 'アイテムリクエストがキャンセルされました。',
    'Item_Requested' => 'アイテムをリクエストしました',
    'License_Checkin_Notification' => 'ライセンスをチェックインしました',
    'License_Checkout_Notification' => 'ライセンスがチェックアウトされました',
    'Low_Inventory_Report' => '在庫減レポート',
    'a_user_canceled' => 'ユーザーがアイテムリクエストをキャンセルしました。',
    'a_user_requested' => 'ユーザーがアイテムをリクエストしています',
    'acceptance_asset_accepted' => 'ユーザーがアイテムを承認しました',
    'acceptance_asset_declined' => 'ユーザーがアイテムを拒否しました',
    'accessory_name' => '付属品名:',
    'additional_notes' => '追記:',
    'admin_has_created' => '管理者が:web でアカウントを作成しました。',
    'asset' => '資産:',
    'asset_name' => '資産名:',
    'asset_requested' => '資産リクエスト',
    'asset_tag' => '資産タグ',
    'assets_warrantee_alert' => ':threshold 日以内に:count 個の資産に保証期間が切れます。|:threshold 日以内に :count 個の資産に保証期間が切れます。',
    'assigned_to' => '割り当て先',
    'best_regards' => '敬具',
    'canceled' => 'キャンセル済:',
    'checkin_date' => 'チェックイン日:',
    'checkout_date' => 'チェックアウト日:',
    'checkedout_from' => 'からチェックアウトしました',
    'checkedin_from'  => 'チェックイン元',
    'checked_into' => 'チェックインされました',
    'click_on_the_link_accessory' => '次のリンクをクリックして、アクセサリーを受け取ったことを確認してください。',
    'click_on_the_link_asset' => '次のリンクをクリックして、資産を受け取ったことを確認してください。',
    'click_to_confirm' => ':web account: を有効にする為に、次のリンクをクリックしてください。',
    'current_QTY' => '現在の数量',
    'days' => '日数',
    'expecting_checkin_date' => 'チェックイン予定日:',
    'expires' => '保証失効日',
    'hello' => 'こんにちは。',
    'hi' => 'こんにちは',
    'i_have_read' => '私は使用条件を読み、同意し、このアイテムを受け取りました。',
    'inventory_report' => 'インベントリレポート',
    'item' => 'アイテム:',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => ':threshold 日後に:count ライセンスが失効します。',
    'link_to_update_password' => '次のリンクをクリックして、パスワードを更新してください。 :web password:',
    'login' => 'ログイン:',
    'login_first_admin' => '以下の新しいログイン情報を使用して、Snipe-ITにログインします。',
    'low_inventory_alert' => '最小在庫を下回っているか、すぐに少なくなる :count のアイテムがあります。',
    'min_QTY' => '分数',
    'name' => '名前',
    'new_item_checked' => 'あなたの名前で新しいアイテムがチェックアウトされました。詳細は以下の通りです。',
    'notes' => '備考',
    'password' => 'パスワード:',
    'password_reset' => 'パスワードリセット',
    'read_the_terms' => '下記の利用規約をお読みください。',
    'read_the_terms_and_click' => '以下の利用規約をお読みください。 下部のリンクをクリックして、利用規約を読み、同意し、資産を受け取ったことを確認してください。',
    'requested' => '要求済:',
    'reset_link' => 'パスワードリセットのリンク',
    'reset_password' => 'パスワードをリセットするにはここをクリック:',
    'rights_reserved' => 'All rights reserved.',
    'serial' => 'シリアル',
    'snipe_webhook_test' => 'Snipe-IT 統合テスト',
    'snipe_webhook_summary' => 'Snipe-IT 統合テストの概要',
    'supplier' => '仕入先',
    'tag' => 'タグ',
    'test_email' => 'Snipe-ITからのテストメール',
    'test_mail_text' => 'これはSnipe-IT資産管理システムのテストです。あなたがこれを読めているなら、メール機能は動作しています:)',
    'the_following_item' => '次の項目がチェックインされています: ',
    'to_reset' => 'パスワードをリセットするには、: web のフォームを完了します:',
    'type' => 'タイプ',
    'upcoming-audits' => ':threshold 日以内に監査が行われる資産は :count 個です。|:threshold 日以内に監査が行われる予定の資産が :count 個あります。',
    'user' => 'ユーザ',
    'username' => 'ユーザ名',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'ようこそ、 :name さん',
    'welcome_to' => ':web にようこそ!',
    'your_assets' => 'あなたの資産を表示',
    'your_credentials' => 'Snipe-IT クレデンシャル',
    'mail_sent' => 'Mail sent successfully!',
];

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/ja-JP/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => '付属品をチェックインしました',
    'Accessory_Checkout_Notification' => '付属品をチェックアウトしました',
    'Asset_Checkin_Notification' => '資産をチェックインしました',
    'Asset_Checkout_Notification' => '資産はチェックアウトされました',
    'Confirm_Accessory_Checkin' => 'アクセサリーのチェックインを承認してください。',
    'Confirm_Asset_Checkin' => '資産チェックインを承認してください。',
    'Confirm_accessory_delivery' => 'アクセサリーの受取りを承認してください。',
    'Confirm_asset_delivery' => '資産の受取りを承認してください。',
    'Confirm_consumable_delivery' => '消耗品の受取りを承認してください。',
    'Confirm_license_delivery' => 'ライセンスの受取りを承認してください。',
    'Consumable_checkout_notification' => '消耗品はチェックアウトしました',
    'Days' => '日数',
    'Expected_Checkin_Date' => 'チェックアウトされた資産は:date にチェックインされる予定です',
    'Expected_Checkin_Notification' => 'リマインダー: :name のチェックイン期限が近づいています',
    'Expected_Checkin_Report' => '予想される資産チェックインレポート',
    'Expiring_Assets_Report' => '保証切れ資産レポート',
    'Expiring_Licenses_Report' => '有効期限切れのライセンスレポート',
    'Item_Request_Canceled' => 'アイテムリクエストがキャンセルされました。',
    'Item_Requested' => 'アイテムをリクエストしました',
    'License_Checkin_Notification' => 'ライセンスをチェックインしました',
    'License_Checkout_Notification' => 'ライセンスがチェックアウトされました',
    'Low_Inventory_Report' => '在庫減レポート',
    'a_user_canceled' => 'ユーザーがアイテムリクエストをキャンセルしました。',
    'a_user_requested' => 'ユーザーがアイテムをリクエストしています',
    'acceptance_asset_accepted' => 'ユーザーがアイテムを承認しました',
    'acceptance_asset_declined' => 'ユーザーがアイテムを拒否しました',
    'accessory_name' => '付属品名',
    'additional_notes' => '追記',
    'admin_has_created' => '管理者が:web でアカウントを作成しました。',
    'asset' => '資産',
    'asset_name' => '資産名',
    'asset_requested' => '資産リクエスト',
    'asset_tag' => '資産タグ',
    'assets_warrantee_alert' => ':threshold 日以内に:count 個の資産に保証期間が切れます。|:threshold 日以内に :count 個の資産に保証期間が切れます。',
    'assigned_to' => '割り当て先',
    'best_regards' => '敬具',
    'canceled' => 'キャンセル済',
    'checkin_date' => 'チェックイン日',
    'checkout_date' => '検査日',
    'checkedout_from' => 'からチェックアウトしました',
    'checkedin_from'  => 'チェックイン元',
    'checked_into' => 'チェックインされました',
    'click_on_the_link_accessory' => '次のリンクをクリックして、アクセサリーを受け取ったことを確認してください。',
    'click_on_the_link_asset' => '次のリンクをクリックして、資産を受け取ったことを確認してください。',
    'click_to_confirm' => ':web account: を有効にする為に、次のリンクをクリックしてください。',
    'current_QTY' => '現在の数量',
    'days' => '日数',
    'expecting_checkin_date' => '希望するチェックイン日',
    'expires' => '保証失効日',
    'hello' => 'こんにちは。',
    'hi' => 'こんにちは',
    'i_have_read' => '私は使用条件を読み、同意し、このアイテムを受け取りました。',
    'inventory_report' => 'インベントリレポート',
    'item' => '品目',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => ':threshold 日後に:count ライセンスが失効します。',
    'link_to_update_password' => '次のリンクをクリックして、パスワードを更新してください。 :web password:',
    'login' => 'ログイン:',
    'login_first_admin' => '以下の新しいログイン情報を使用して、Snipe-ITにログインします。',
    'low_inventory_alert' => '最小在庫を下回っているか、すぐに少なくなる :count のアイテムがあります。',
    'min_QTY' => '分数',
    'name' => '名前',
    'new_item_checked' => 'あなたの名前で新しいアイテムがチェックアウトされました。詳細は以下の通りです。',
    'notes' => '備考',
    'password' => 'パスワード',
    'password_reset' => 'パスワードリセット',
    'read_the_terms' => '下記の利用規約をお読みください。',
    'read_the_terms_and_click' => '以下の利用規約をお読みください。 下部のリンクをクリックして、利用規約を読み、同意し、資産を受け取ったことを確認してください。',
    'requested' => '要求済',
    'reset_link' => 'パスワードリセットのリンク',
    'reset_password' => 'パスワードをリセットするにはここをクリック:',
    'rights_reserved' => 'All rights reserved.',
    'serial' => 'シリアル',
    'snipe_webhook_test' => 'Snipe-IT 統合テスト',
    'snipe_webhook_summary' => 'Snipe-IT 統合テストの概要',
    'supplier' => '仕入先',
    'tag' => 'タグ',
    'test_email' => 'Snipe-ITからのテストメール',
    'test_mail_text' => 'これはSnipe-IT資産管理システムのテストです。あなたがこれを読めているなら、メール機能は動作しています:)',
    'the_following_item' => '次の項目がチェックインされています: ',
    'to_reset' => 'パスワードをリセットするには、: web のフォームを完了します:',
    'type' => 'タイプ',
    'upcoming-audits' => ':threshold 日以内に監査が行われる資産は :count 個です。|:threshold 日以内に監査が行われる予定の資産が :count 個あります。',
    'user' => 'ユーザ',
    'username' => 'ユーザ名',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'ようこそ、 :name さん',
    'welcome_to' => ':web にようこそ!',
    'your_assets' => 'あなたの資産を表示',
    'your_credentials' => 'Snipe-IT クレデンシャル',
    'mail_sent' => 'Mail sent successfully!',
];
